@@ -1,6 +1,7 @@
 /*
     SPDX-License-Identifier: GPL-2.0-or-later
     SPDX-FileCopyrightText: 2009 Alexander Rieder <alexanderrieder@gmail.com>
+    SPDX-FileCopyrightText: 2018-2022 by Alexander Semke (alexander.semke@web.de)
 */
 
 #include "testmaxima.h"
@@ -18,8 +19,6 @@
 
 #include <config-cantorlib.h>
 
-#include <QDebug>
-
 QString TestMaxima::backendName()
 {
     return QLatin1String("maxima");
@@ -66,11 +65,7 @@ void TestMaxima::testPlot()
         waitForSignal(e, SIGNAL(gotResult()));
     }
 
-#ifdef WITH_EPS
-    QCOMPARE( e->result()->type(), (int)Cantor::EpsResult::Type );
-#else
     QCOMPARE( e->result()->type(), (int)Cantor::ImageResult::Type );
-#endif
     QVERIFY( !e->result()->data().isNull() );
     QVERIFY( e->errorMessage().isNull() );
 }
@@ -97,11 +92,7 @@ void TestMaxima::testPlotWithAnotherTextResults()
 
     QCOMPARE(e->results().at(0)->data().toString(), QLatin1String("4"));
 
-#ifdef WITH_EPS
-    QCOMPARE( e->results().at(1)->type(), (int)Cantor::EpsResult::Type );
-#else
     QCOMPARE( e->results().at(1)->type(), (int)Cantor::ImageResult::Type );
-#endif
     QVERIFY( !e->results().at(1)->data().isNull() );
 
     QCOMPARE(e->results().at(2)->data().toString(), QLatin1String("16"));
@@ -115,6 +106,42 @@ void TestMaxima::testInvalidSyntax()
     QVERIFY( e->status()==Cantor::Expression::Error );
 }
 
+void TestMaxima::testWarning01()
+{
+    auto* e = evalExp( QLatin1String("rat(0.75*10)") );
+
+    QVERIFY(e != nullptr);
+    QVERIFY(e->results().size() == 2); //two results, the warning and the actual result of the calculation
+
+    //the actual warning string "rat: replaced 7.5 by 15/2 = 7.5" which we don't checked since it's translated,
+    //we just check it's existance.
+    auto* result = dynamic_cast<Cantor::TextResult*>(e->results().at(0));
+    QVERIFY(e != nullptr);
+    QVERIFY(result->data().toString().isEmpty() == false);
+    QVERIFY(result->isWarning() == true);
+
+    //the result of the calculation
+    QCOMPARE(e->results().at(1)->data().toString(), QLatin1String("15/2"));
+}
+
+/*!
+ * test the output of the tex() function which is similarly formatted as other functions producing warning
+ * but which shouldn't be treated as a warning.
+ * */
+void TestMaxima::testWarning02()
+{
+    auto* e = evalExp( QLatin1String("tex(\"sin(x)\")") );
+
+    QVERIFY(e != nullptr);
+    QVERIFY(e->results().size() == 2); //two results, the TeX output and an additional 'false'
+
+    //the actual TeX string is of no interest for us, we just check it's existance.
+    auto* result = dynamic_cast<Cantor::TextResult*>(e->results().at(0));
+    QVERIFY(e != nullptr);
+    QVERIFY(result->data().toString().isEmpty() == false);
+    QVERIFY(result->isWarning() == false);
+}
+
 void TestMaxima::testExprNumbering()
 {
     Cantor::Expression* e=evalExp( QLatin1String("kill(labels)") ); //first reset the labels
@@ -298,6 +325,31 @@ void TestMaxima::testVariableModel()
     QCOMPARE(value2.toString(),QLatin1String("[1,2,3]"));
 }
 
+void TestMaxima::testLispMode01()
+{
+    //switch to the Lisp-mode
+    auto* e1 = evalExp(QLatin1String("to_lisp();"));
+    QVERIFY(e1 != nullptr);
+
+    //evaluate a Lisp command and check the result
+    auto* e2 = evalExp(QLatin1String("(cons 'a 'b)"));
+    QVERIFY(e2 != nullptr);
+    QVERIFY(e2->result() != nullptr);
+    QCOMPARE(cleanOutput(e2->result()->data().toString()), QLatin1String("(A . B)"));
+
+    //switch back to Maxima mode
+    auto* e3 = evalExp(QLatin1String("(to-maxima)"));
+    QVERIFY(e3 != nullptr);
+
+    //evaluate a simple Maxima command
+    auto* e4 = evalExp(QLatin1String("5+5"));
+    QVERIFY(e4 != nullptr);
+
+    //TODO: doesn't work in the test, works in Cantor though...
+//     QVERIFY(e4->result() != nullptr);
+//     QCOMPARE(cleanOutput(e4->result()->data().toString()), QLatin1String("10"));
+}
+
 void TestMaxima::testLoginLogout()
 {
     // Logout from session twice and all must works fine
