@@ -1,22 +1,7 @@
 /*
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License
-    as published by the Free Software Foundation; either version 2
-    of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA  02110-1301, USA.
-
-    ---
-    Copyright (C) 2010 Miha Čančula <miha.cancula@gmail.com>
- */
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2010 Miha Čančula <miha.cancula@gmail.com>
+*/
 
 #ifndef CANTOR_DEFAULTVARIABLEMODEL_H
 #define CANTOR_DEFAULTVARIABLEMODEL_H
@@ -58,6 +43,8 @@ public:
      */
     struct Variable
     {
+        Variable(): size(0) {}
+        Variable(QString name, QString value, size_t size = 0): name(name), value(value), size(size) {}
         /**
          * The variable's name
          */
@@ -66,6 +53,11 @@ public:
          * The variable's value, represented as a string
          */
         QString value;
+
+        /**
+         * Optional parameter. Size of variable in bytes
+         */
+        size_t size;
     };
 
     /**
